@@ -12,62 +12,55 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-format.corpus_frame <- function(x, chars = NULL, justify = "left",
-                                na.encode = TRUE, quote = FALSE,
-                                na.print = NULL, print.gap = NULL, ...)
+format.corpus_frame <- function(x, chars = NULL, na.encode = TRUE,
+                                quote = FALSE, na.print = NULL,
+                                print.gap = NULL, ..., justify = "none")
 {
     if (is.null(x)) {
         return(invisible(NULL))
-    }
-
-    if (!is.data.frame(x)) {
+    } else if (!is.data.frame(x)) {
         stop("argument is not a data frame")
     }
 
     with_rethrow({
         chars <- as_chars("chars", chars)
-        justify <- as_justify("justify", justify)
         na.encode <- as_option("na.encode", na.encode)
         quote <- as_option("quote", quote)
         na.print <- as_na_print("na.print", na.print)
         print.gap <- as_print_gap("print.gap", print.gap)
+        justify <- as_justify("justify", justify)
     })
 
-    if ((stretch <- is.null(chars))) {
-        width <- getOption("width")
-        rn <- rownames(x)
-        rn[is.na(rn)] <- "NA"
-        rownames_width <- max(0, utf8_width(rn))
-
-        gap <- if (is.null(print.gap)) 1 else print.gap
-
-        utf8 <- Sys.getlocale("LC_CTYPE") != "C"
-        ellipsis <- if (utf8) 1 else 3
-        quotes <- if (quote) 2 else 0
-
-        chars_min <- 24
-        chars_max <- (width - ellipsis - quotes
-                      - gap - rownames_width)
-        chars_max <- max(chars_max, chars_min)
-        chars <- chars_max
+    if (is.null(na.print)) {
+        na.print <- if (quote) "NA" else "<NA>"
+    }
+    if (is.null(print.gap)) {
+        print.gap <- 1L
     }
 
     nr <- .row_names_info(x, 2L)
     nc <- ncol(x)
     names <- names(x)
-    names[is.na(names)] <- "NA"
+    names[is.na(names)] <- "<NA>"
+    rownames <- rownames(x)
+    stopifnot(!anyNA(rownames))
 
-    cols <- vector("list", nc)
+    if ((stretch <- is.null(chars))) {
+        width <- getOption("width")
+        rw <- max(0L, utf8_width(rownames))
 
-    if (stretch) {
-        chars_left <- chars_max
+        utf8 <- output_utf8()
+        ellipsis <- if (utf8) 1 else 3
+        quotes <- if (quote) 2 else 0
+
+        chars_min <- 24
+        chars_max <- max(chars_min, width - ellipsis - quotes - print.gap - rw)
+        chars <- chars_left <- chars_max
     }
 
-    for (i in seq_len(nc)) {
-        elt <- x[[i]]
-        cl <- class(elt)
-        fac <- FALSE
+    cols <- vector("list", length(x))
 
+    for (i in seq_len(nc)) {
         if (stretch) {
             if (chars_left < chars_min) {
                 # allow wrap to next line
@@ -77,6 +70,13 @@ format.corpus_frame <- function(x, chars = NULL, justify = "left",
             }
         }
 
+        elt <- x[[i]]
+        cl <- class(elt)
+
+        # determine the name width
+        w <- utf8_width(names[[i]])
+
+        # convert factor to character
         if (is.factor(elt) && (identical(cl, "factor")
                                || identical(cl, c("AsIs", "factor")))) {
             elt <- structure(as.character(elt), names = names(elt),
@@ -84,42 +84,40 @@ format.corpus_frame <- function(x, chars = NULL, justify = "left",
             cl <- class(elt)
         }
 
+        # format character using utf8_format
         if (is.character(elt) && (identical(cl, "character")
                                   || identical(cl, "AsIs"))) {
-            w <- utf8_width(names[[i]])
             cols[[i]] <- utf8_format(elt, chars = chars, justify = justify,
                                      width = w, na.encode = na.encode,
                                      quote = quote, na.print = na.print)
             char <- TRUE
-
-        } else {
+        } else { # format others using S3
             cols[[i]] <- format(elt, chars = chars, justify = justify,
-                                na.encode = na.encode, quote = quote,
-                                na.print = na.print,
+                                width = w, na.encode = na.encode,
+                                quote = quote, na.print = na.print,
                                 print.gap = print.gap, ...)
             char <- is_corpus_text(elt)
         }
 
-        if (char) {
-            # use same justification for column and name
-            names[[i]] <- utf8_format(names[[i]],
-                                      chars = .Machine$integer.max,
-                                      justify = justify,
-                                      width = max(0, utf8_width(cols[[i]])),
-                                      na.encode = TRUE, na.print = "NA")
+        # determine column width
+        w <- max(w, utf8_width(cols[[i]], quote = quote), na.rm = TRUE)
+        if (anyNA(cols[[i]])) {
+            naw <- if (char) utf8_width(na.print) else 2 # NA
+            w <- max(w, naw)
+        }
+
+        # format the name, using element justification
+        if (!char) {
+            names[[i]] <- utf8_format(names[[i]], chars = .Machine$integer.max,
+                                      justify = "right", width = w)
         }
 
         if (stretch) {
-            cn <- names[[i]]
-            cw <- utf8_width(cols[[i]], quote = quote)
-            cw[is.na(cw)] <- if (char && !quote) 4 else 2
-
-            w <- max(cw, utf8_width(cn))
             if (w > chars_left) {
                 # wrapped to next line
-                chars_left <- chars_max - gap - w
+                chars_left <- chars_max - print.gap - w
             } else {
-                chars_left <- chars_left - gap - w
+                chars_left <- chars_left - print.gap - w
             }
 
             if (chars_left < 0) {
@@ -141,10 +139,10 @@ format.corpus_frame <- function(x, chars = NULL, justify = "left",
 
     # Should we truncate long names? R cuts them off at 256 characters.
     names(cols) <- names
-    row.names <- row.names(x)
 
     structure(cols, class = c("corpus_frame", "data.frame"),
-              row.names = row.names)
+              row.names = rownames)
+
 }
 
 
@@ -156,9 +154,7 @@ print.corpus_frame <- function(x, rows = 20L, chars = NULL, digits = NULL,
 {
     if (is.null(x)) {
         return(invisible(NULL))
-    }
-
-    if (!is.data.frame(x)) {
+    } else if (!is.data.frame(x)) {
         stop("argument is not a data frame")
     }
 
@@ -210,11 +206,9 @@ print.corpus_frame <- function(x, rows = 20L, chars = NULL, digits = NULL,
         xsub <- x
     }
 
-    justify <- if (right) "right" else "left"
-
-    fmt <- format.corpus_frame(xsub, chars = chars, digits = digits,
-                               na.encode = TRUE, quote = quote,
-                               na.print = na.print, justify = justify)
+    fmt <- format.corpus_frame(xsub, chars = chars, na.encode = FALSE,
+                               na.print = na.print, quote = quote,
+                               print.gap = print.gap, digits = digits)
     m <- as.matrix(fmt)
     storage.mode(m) <- "character"
 
@@ -222,8 +216,10 @@ print.corpus_frame <- function(x, rows = 20L, chars = NULL, digits = NULL,
         rownames(m) <- row.names
     }
 
-    utf8_print(m, chars = .Machine$integer.max, quote = FALSE,
-               print.gap = print.gap, right = TRUE, max = max,
+    utf8_print(m, chars = .Machine$integer.max, quote = quote,
+               na.print = na.print, print.gap = print.gap,
+               right = right, max = max, names = style_bold,
+               rownames = style_faint, escapes = style_faint,
                display = display)
 
     if (n == 0) {
@@ -231,12 +227,14 @@ print.corpus_frame <- function(x, rows = 20L, chars = NULL, digits = NULL,
     } else if (trunc) {
         name_width <- max(0, utf8_width(rownames(m)))
 
-        ellipsis <- ifelse(Sys.getlocale("LC_CTYPE") == "C", ".", "\u22ee")
+        ellipsis <- ifelse(output_utf8(), "\u22ee", ".")
         ellipsis <- substr(ellipsis, 1, name_width)
         gap <- if (is.null(print.gap)) 1 else print.gap
-
         space <- format(ellipsis, width = name_width + gap)
-        cat(sprintf("%s(%d rows total)\n", space, n))
+        if (output_ansi()) {
+            space <- paste0("\x1b[", style_faint, "m", space, "\x1b[0m")
+        }
+        cat(space, sprintf("(%d rows total)\n", n), sep = "")
     }
 
     invisible(x)
