@@ -14,33 +14,30 @@
  * limitations under the License.
  */
 
-#include "text.h"
+#include "../lib/utf8lite/src/utf8lite.h"
 #include "unicode/sentbreakprop.h"
 #include "sentscan.h"
 
 
 void corpus_sentscan_make(struct corpus_sentscan *scan,
-			  const struct corpus_text *text,
+			  const struct utf8lite_text *text,
 			  int flags)
 {
 	scan->text = *text;
-	scan->text_attr = text->attr & ~CORPUS_TEXT_SIZE_MASK;
 	scan->flags = flags;
 
-	corpus_text_iter_make(&scan->iter, text);
+	utf8lite_text_iter_make(&scan->iter, text);
 	corpus_sentscan_reset(scan);
 }
 
 
 #define SCAN() \
 	do { \
-		scan->current.attr |= scan->attr; \
 		scan->ptr = scan->iter_ptr; \
 		scan->code = scan->iter.current; \
-		scan->attr = scan->iter.attr; \
 		scan->prop = scan->iter_prop; \
 		scan->iter_ptr = scan->iter.ptr; \
-		if (corpus_text_iter_advance(&scan->iter)) { \
+		if (utf8lite_text_iter_advance(&scan->iter)) { \
 			scan->iter_prop = sent_break(scan->iter.current); \
 		} else { \
 			scan->iter_prop = -1; \
@@ -55,9 +52,8 @@ void corpus_sentscan_make(struct corpus_sentscan *scan,
 	do { \
 		while (scan->iter_prop == SENT_BREAK_EXTEND \
 				|| scan->iter_prop == SENT_BREAK_FORMAT) { \
-			scan->attr |= scan->iter.attr; \
 			scan->iter_ptr = scan->iter.ptr; \
-			if (corpus_text_iter_advance(&scan->iter)) { \
+			if (utf8lite_text_iter_advance(&scan->iter)) { \
 				scan->iter_prop = \
 					sent_break(scan->iter.current); \
 			} else { \
@@ -92,20 +88,19 @@ void corpus_sentscan_make(struct corpus_sentscan *scan,
 
 void corpus_sentscan_reset(struct corpus_sentscan *scan)
 {
-	scan->current.ptr = 0;
-	scan->current.attr = 0;
+	scan->current.ptr = NULL;
+	scan->current.attr = scan->iter.text_attr & ~UTF8LITE_TEXT_SIZE_MASK;
 	scan->type = CORPUS_SENT_NONE;
 
-	corpus_text_iter_reset(&scan->iter);
+	utf8lite_text_iter_reset(&scan->iter);
 	scan->ptr = scan->iter.ptr;
 
-	if (corpus_text_iter_advance(&scan->iter)) {
+	if (utf8lite_text_iter_advance(&scan->iter)) {
 		scan->code = scan->iter.current;
-		scan->attr = scan->iter.attr;
 		scan->prop = sent_break(scan->code);
 
 		scan->iter_ptr = scan->iter.ptr;
-		if (corpus_text_iter_advance(&scan->iter)) {
+		if (utf8lite_text_iter_advance(&scan->iter)) {
 			scan->iter_prop = sent_break(scan->iter.current);
 		} else {
 			scan->iter_prop = -1;
@@ -113,7 +108,6 @@ void corpus_sentscan_reset(struct corpus_sentscan *scan)
 		MAYBE_EXTEND();
 	} else {
 		scan->code = 0;
-		scan->attr = 0;
 		scan->prop = -1;
 		scan->iter_ptr = NULL;
 		scan->iter_prop = -1;
@@ -124,7 +118,7 @@ void corpus_sentscan_reset(struct corpus_sentscan *scan)
 
 static int has_future_lower(const struct corpus_sentscan *scan)
 {
-	struct corpus_text_iter iter;
+	struct utf8lite_text_iter iter;
 	int prop, ret;
 
 	if (scan->iter_prop < 0) {
@@ -160,7 +154,7 @@ static int has_future_lower(const struct corpus_sentscan *scan)
 			break;
 		}
 
-		if (corpus_text_iter_advance(&iter)) {
+		if (utf8lite_text_iter_advance(&iter)) {
 			prop = sent_break(iter.current);
 		} else {
 			ret = 0;
@@ -176,7 +170,7 @@ out:
 int corpus_sentscan_advance(struct corpus_sentscan *scan)
 {
 	scan->current.ptr = (uint8_t *)scan->ptr;
-	scan->current.attr = 0;
+	scan->current.attr = scan->iter.text_attr & ~UTF8LITE_TEXT_SIZE_MASK;
 	scan->type = CORPUS_SENT_NONE;
 
 NoBreak:
@@ -391,8 +385,8 @@ STerm_Close_Sp:
 Break:
 	scan->current.attr |= (size_t)(scan->ptr - scan->current.ptr);
 
-	if (CORPUS_TEXT_SIZE(&scan->current) == 0) {
-		if (CORPUS_TEXT_SIZE(&scan->text) == 0 && !scan->at_end) {
+	if (UTF8LITE_TEXT_SIZE(&scan->current) == 0) {
+		if (UTF8LITE_TEXT_SIZE(&scan->text) == 0 && !scan->at_end) {
 			scan->at_end = 1;
 			return 1;
 		} else {
