@@ -115,12 +115,12 @@ int corpus_table_reinit(struct corpus_table *tab, int min_capacity)
 		size = corpus_table_size_min(min_capacity, size);
 		capacity = (int)(CORPUS_TABLE_LOAD_FACTOR * size);
 
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wtype-limits"
+//#pragma GCC diagnostic push
+//#pragma GCC diagnostic ignored "-Wtype-limits"
 		// gcc emits a warning if sizeof(size_t) > sizeof(unsigned)
 
 		if ((size_t)size > SIZE_MAX / sizeof(*items)) {
-#pragma GCC diagnostic pop
+//#pragma GCC diagnostic pop
 
 			err = CORPUS_ERROR_OVERFLOW;
 			corpus_log(err, "table size (%d)"
