@@ -10,7 +10,7 @@ test_that("'sentences' splits according to UAX #29 (Examples)", {
         structure(class = c("corpus_frame", "data.frame"),
             data.frame(parent = factor(c("1", "1", "2", "2")),
                        index  = c(1L, 2L, 1L, 2L),
-                       text   = as_text(c("He said, 'Are you going?' ",
+                       text   = as_corpus_text(c("He said, 'Are you going?' ",
                                           "John Shook his head.",
                                           "'Are you going?' ",
                                           "John asked"),
@@ -27,7 +27,7 @@ test_that("'sentences' splits according to UAX #29 (Fig. 3)", {
         structure(class = c("corpus_frame", "data.frame"),
             data.frame(parent = factor(c("1", "2", "3", "4", "5")),
                        index  = c(1L, 1L, 1L, 1L, 1L),
-                       text   = as_text(c("c.d", "3.4", "U.S.",
+                       text   = as_corpus_text(c("c.d", "3.4", "U.S.",
                                           "the resp. leaders are",
                                           "etc.)' '(the"),
                                         filter = f),
@@ -44,7 +44,7 @@ test_that("'sentences' splits according to UAX #29 (Fig. 4)", {
         structure(class = c("corpus_frame", "data.frame"),
             data.frame(parent = factor(c("1", "1", "2", "2", "3", "3")),
                        index  = c(1L, 2L, 1L, 2L, 1L, 2L),
-                       text   = as_text(c("She said 'See spot run.'  ",
+                       text   = as_corpus_text(c("She said 'See spot run.'  ",
                                           "John shook his head.",
                                           "etc.",
                                           "\u5b83\u4eec\u6307",
@@ -60,7 +60,7 @@ test_that("'sentences' cannot handle abbreviations without suppressions", {
     expect_equal(text_split("Mr. Jones", "sentences", filter = f),
         structure(class = c("corpus_frame", "data.frame"),
             data.frame(parent = factor(c("1", "1")), index = c(1L, 2L),
-                       text = as_text(c("Mr. ", "Jones"), filter = f),
+                       text = as_corpus_text(c("Mr. ", "Jones"), filter = f),
                        row.names = NULL)))
 })
 
@@ -69,7 +69,7 @@ test_that("'sentences' works on length-0 arguments values", {
     expect_equal(text_split(c(), "sentences"),
         structure(class = c("corpus_frame", "data.frame"),
             data.frame(parent = factor(c()), index = integer(),
-                       text = as_text(c()), row.names = NULL)))
+                       text = as_corpus_text(c()), row.names = NULL)))
 })
 
 
@@ -79,20 +79,20 @@ test_that("'sentences' works on empty and missing values", {
             data.frame(parent = factor(c("1", "2", "4", "5"),
                                        levels = as.character(1:5)),
                        index  = c(1L, 1L, 1L, 1L),
-                       text   = as_text(c("1", "2", "", "5")),
+                       text   = as_corpus_text(c("1", "2", "", "5")),
                        row.names = NULL)))
 })
 
 
 test_that("'sentences' uses names if its argument has them", {
-    text <- as_text(c(a="First sentence. Second.", b="Third sentence!"))
+    text <- as_corpus_text(c(a="First sentence. Second.", b="Third sentence!"))
     sents <- text_split(text, "sentences")
     expect_equal(sents,
         structure(class = c("corpus_frame", "data.frame"),
             data.frame(parent = factor(c("a", "a", "b"),
                                        levels = c("a", "b")),
                        index = c(1L, 2L, 1L),
-                       text = as_text(c("First sentence. ", "Second.",
+                       text = as_corpus_text(c("First sentence. ", "Second.",
                                         "Third sentence!")),
                        row.names = NULL,
                        stringsAsFactors = FALSE)))
@@ -146,4 +146,6 @@ test_that("'sentences' should work on S3 objects", {
     sents <- text_split(x, "sentences")
     sents2 <- text_split(x2, "sentences")
     expect_equal(sents, sents2)
+
+    remove("as.character.upper", envir = .GlobalEnv)
 })
